@@ -1,6 +1,6 @@
 // Copyright (C) 2014-2015 Bart Smeets
 // Copyright (C) 2015-2016 Bart Smeets and Iñaki Ucar
-// Copyright (C) 2016-2019 Iñaki Ucar
+// Copyright (C) 2016-2020 Iñaki Ucar
 //
 // This file is part of simmer.
 //
@@ -36,6 +36,8 @@
 #include <simmer/resource/priority.h>
 #include <simmer/resource/preemptive.h>
 
+#include <simmer/monitor/memory.h>
+
 namespace simmer {
 
   inline Simulator::~Simulator() {
@@ -145,19 +147,21 @@ namespace simmer {
     return arrival;
   }
 
-  inline void Simulator::record_ongoing(bool per_resource) const {
+  inline RData Simulator::get_ongoing(bool per_resource) const {
+    MemMonitor mon;
     foreach_ (const ArrMap::value_type& itr1, arrival_map) {
       if (dynamic_cast<Batched*>(itr1.first) || !itr1.first->is_monitored())
         continue;
       if (!per_resource)
-        mon->record_end(itr1.first->name, itr1.first->get_start(), R_NaReal, R_NaReal, false);
+        mon.record_end(itr1.first->name, itr1.first->get_start(), R_NaReal, R_NaReal, false);
       else foreach_ (const EntMap::value_type& itr2, resource_map) {
         double start = itr1.first->get_start(itr2.second->name);
         if (start < 0)
           continue;
-        mon->record_release(itr1.first->name, start, R_NaReal, R_NaReal, itr2.second->name);
+        mon.record_release(itr1.first->name, start, R_NaReal, R_NaReal, itr2.second->name);
       }
     }
+    return mon.get_arrivals(per_resource);
   }
 
   inline void Simulator::broadcast(const VEC<std::string>& signals) {
